@@ -60,10 +60,6 @@ def compile_page(ish, file_name):
     with open("page_text.txt", "a", encoding=unicode) as save:
         save.write(page_text)
     print(PHJF_text + "\033[33m%s" % "正在编译数据...")
-    open_lists = open("lists_info.txt", "r")
-    for line in open_lists.readlines():
-        curline = line.strip().split(" ")
-        lists_info.append(curline[:])
     if ish == "json":
         with open(f"{file_name}.json", 'a', encoding=unicode) as save:
             json_file = json.dumps(lists_info, sort_keys=False, ensure_ascii=False, indent=4, separators=(',', ': '))
@@ -81,7 +77,7 @@ def compile_page(ish, file_name):
 
 def run_server():
     print(PHJF_text + "\033[33m%s" % "正在启动本地服务器...")
-    os.system('python3 open_web.py')
+    os.system('python3 PHJF/open_web.py')
 
 
 @atexit.register
